package com.ruoyi.app.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ruoyi.app.domain.TbMemberMiddle;
import com.ruoyi.app.domain.vo.AppFamilyVo;
import com.ruoyi.app.service.ITbMemberMiddleService;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.app.mapper.TbFamilyMapper;
import com.ruoyi.app.domain.TbFamily;
import com.ruoyi.app.service.ITbFamilyService;

import java.util.Date;
import java.util.List;

/**
 * 家族Service业务层处理
 *
 * @author Alex
 * @date 2020-09-28
 */
@Service
public class TbFamilyServiceImpl extends ServiceImpl<TbFamilyMapper, TbFamily> implements ITbFamilyService {

    @Autowired
    private ITbFamilyService familyService;
    @Autowired
    private ITbMemberMiddleService middleService;

    /**
     * 根据会员id获取家族列表
     * @param uid
     * @return
     */
    @Override
    public List<TbFamily> selectByUserId(Long uid) {
        return baseMapper.selectByUserId(uid);
    }
    /**
     * 根据成员id获取家族列表
     * @param mid
     * @return
     */
    @Override
    public List<TbFamily> selectByMemberId(Long mid) {
        return baseMapper.selectByMemberId(mid);
    }

    @Override
    public List<AppFamilyVo> pageList(LambdaQueryWrapper<TbFamily> wrapper){
        return baseMapper.pageList(wrapper);
    }


    @Override
    public boolean saveFamily(TbFamily family){
        if (familyService.save(family)) {
            // TODO 如果是APP端添加，则把添加人设置为家族管理员
            family.setCode(StringUtils.codeFormat(family.getId()));
        }
        return familyService.updateById(family);
    }

    @Override
    public TbFamily myFamily(Long memberId) {
        TbMemberMiddle middle = middleService.getOne(new LambdaQueryWrapper<TbMemberMiddle>()
                .eq(TbMemberMiddle::getMemberId, memberId)
                .eq(TbMemberMiddle::getAcquiesce, "Y")
        );
        if (middle == null) {
            // 没有默认家族，则设置第一个家族为默认
            middle = middleService.getOne(new LambdaQueryWrapper<TbMemberMiddle>()
                    .eq(TbMemberMiddle::getMemberId, memberId).last("limit 1")
            );
            if (middle == null) {
                return null;
            }
            middle.setAcquiesce("Y");
            middleService.save(middle);
        }
        TbFamily family = familyService.getOne(new LambdaQueryWrapper<TbFamily>()
                .eq(TbFamily::getId, middle.getFamilyId())
        );
        return family;
    }

    @Override
    public boolean change(Long memberId,Long familyId) {
        List<TbMemberMiddle> middleList = middleService.list(new LambdaQueryWrapper<TbMemberMiddle>()
            .eq(TbMemberMiddle::getMemberId, memberId)
        );
        if (middleList.size() <= 0) {
            return false;
        }
        middleList.forEach(item -> {
            item.setAcquiesce("N");
            if (familyId.equals(item.getFamilyId())) {
                item.setAcquiesce("Y");
            }
        });
        return middleService.updateBatchById(middleList);
    }

}
